"""
Payme API error codes.
"""

# System errors
SYSTEM_ERROR = -32400
INVALID_JSON_RPC = -32600
METHOD_NOT_FOUND = -32601
INVALID_PARAMS = -32602
INTERNAL_ERROR = -32603

# Authorization errors
AUTH_ERROR = -32504
AUTH_TOKEN_INVALID = -32504
AUTH_TOKEN_EXPIRED = -32504

# Business logic errors
INVALID_AMOUNT = -31001
INVALID_ACCOUNT = -31050
COULD_NOT_PERFORM = -31008
COULD_NOT_CANCEL = -31007
TRANSACTION_NOT_FOUND = -31003
TRANSACTION_ALREADY_EXISTS = -31060
TRANSACTION_ALREADY_CANCELLED = -31061
TRANSACTION_ALREADY_COMPLETED = -31062
